Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(828)

Unified Diff: chrome/browser/component_updater/component_updater_service.cc

Issue 9317074: Create an API around UtilityProcessHost and use that from chrome. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/DEPS ('k') | chrome/browser/extensions/extension_management_api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/component_updater/component_updater_service.cc
===================================================================
--- chrome/browser/component_updater/component_updater_service.cc (revision 120256)
+++ chrome/browser/component_updater/component_updater_service.cc (working copy)
@@ -25,8 +25,9 @@
#include "chrome/common/chrome_utility_messages.h"
#include "chrome/common/chrome_version_info.h"
#include "chrome/common/extensions/extension.h"
-#include "content/browser/utility_process_host.h"
#include "content/public/browser/notification_service.h"
+#include "content/public/browser/utility_process_host.h"
+#include "content/public/browser/utility_process_host_client.h"
#include "content/public/common/url_fetcher_delegate.h"
#include "content/public/common/url_fetcher.h"
#include "googleurl/src/gurl.h"
@@ -34,6 +35,8 @@
#include "net/base/load_flags.h"
using content::BrowserThread;
+using content::UtilityProcessHost;
+using content::UtilityProcessHostClient;
// The component updater is designed to live until process shutdown, so
// base::Bind() calls are not refcounted.
@@ -237,9 +240,9 @@
virtual Status RegisterComponent(const CrxComponent& component) OVERRIDE;
// The only purpose of this class is to forward the
// UtilityProcessHost::Client callbacks so CrxUpdateService does
// not have to derive from it because that is refcounted.
- class ManifestParserBridge : public UtilityProcessHost::Client {
+ class ManifestParserBridge : public UtilityProcessHostClient {
public:
explicit ManifestParserBridge(CrxUpdateService* service)
: service_(service) {}
@@ -597,10 +600,9 @@
CrxUpdateService::OnParseUpdateManifestSucceeded(manifest.results());
}
} else {
- UtilityProcessHost* host =
- new UtilityProcessHost(new ManifestParserBridge(this),
- BrowserThread::UI);
- host->set_use_linux_zygote(true);
+ UtilityProcessHost* host = UtilityProcessHost::Create(
+ new ManifestParserBridge(this), BrowserThread::UI);
+ host->EnableZygote();
host->Send(new ChromeUtilityMsg_ParseUpdateManifest(xml));
}
}
@@ -237,9 +240,9 @@
virtual Status RegisterComponent(const CrxComponent& component) OVERRIDE;
// The only purpose of this class is to forward the
- // UtilityProcessHost::Client callbacks so CrxUpdateService does
+ // UtilityProcessHostClient callbacks so CrxUpdateService does
// not have to derive from it because that is refcounted.
« no previous file with comments | « chrome/browser/DEPS ('k') | chrome/browser/extensions/extension_management_api.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698